*********************
WeatherAlerts
*********************


**WeatherAlerts a python package that pulls in the National Weather Service (NWS) Common Alerting Protocol (CAP) Emergency Alerts index feed, parses it and provides interaction with currently active alerts.**

Test/Build Status
------------------
WeatherAlerts has 100% code test coverage, each commit is built and tested in both python 2 and python 3.

CURRENT BUILD STATUS:

.. image:: http://ci.hznet.us/job/WeatherAlertsMaster/badge/icon



Documentation Contents
-----------------------

.. toctree::
   :maxdepth: 2

   about
   nwsdata
   use
   module
   changelog

* :ref:`genindex`
* :ref:`search`


This module is maintained by Zeb Palmer, a Linux Systems Engineer and Professional Photographer who writes a bit of python at work and play. See my other work at `Zeb Palmer <http://www.zebpalmer.com>`_








